@@ -9,6 +9,7 @@ use colored::Colorize;
 pub enum OutputOnly {
     Filenames,
     Folders,
+    Match,
 }
 //
 //Represents parsed CLI options
@@ -23,11 +24,13 @@ pub struct Options {
     pub search_hidden_files: bool,
     pub search_ignored_files: bool,
     pub search_pattern_opt: std::option::Option<String>,
+    pub invert_pattern: bool,
     pub replace_opt: std::option::Option<String>,
     pub simulate_replace: bool,
     pub word_boundary: bool,
     pub case_sensitive: bool,
     pub extensions: Vec<OsString>,
+    pub extension_sets: Vec<OsString>,
     pub search_binary_files: bool,
     pub file_include_pattern_vec: Vec<String>,
     pub file_exclude_pattern_vec: Vec<String>,
@@ -50,11 +53,13 @@ impl Default for Options {
             search_hidden_files: false,
             search_ignored_files: false,
             search_pattern_opt: None,
+            invert_pattern: false,
             replace_opt: None,
             simulate_replace: false,
             word_boundary: false,
             case_sensitive: false,
             extensions: vec![],
+            extension_sets: vec![],
             search_binary_files: false,
             file_include_pattern_vec: vec![],
             file_exclude_pattern_vec: vec![],
@@ -96,6 +101,10 @@ fn generate_option_vec() -> Vec<Option> {
             options.output_only = Some(OutputOnly::Folders);
             Ok(())
         })),
+        Option::new("-m", "--match-only", "Output only matches [false]", Handler::Args0(|options|{
+            options.output_only = Some(OutputOnly::Match);
+            Ok(())
+        })),
         Option::new("-0", "--null", "NULL-separated filename output [false]", Handler::Args0(|options|{
             options.null_separated_output = true;
             Ok(())
@@ -115,6 +124,10 @@ fn generate_option_vec() -> Vec<Option> {
             options.search_pattern_opt = Some(pattern.to_string());
             Ok(())
         })),
+        Option::new("-v", "--invert", "Invert search pattern", Handler::Args0(|options|{
+            options.invert_pattern = true;
+            Ok(())
+        })),
         Option::new("-r", "--replace", "Replace search matches with STRING", Handler::Args1("STRING", |options, replace|{
             options.replace_opt = Some(replace.to_string());
             Ok(())
@@ -131,8 +144,12 @@ fn generate_option_vec() -> Vec<Option> {
             options.case_sensitive = true;
             Ok(())
         })),
-        Option::new("-e", "--extension", "Add search EXTENSION (or)", Handler::Args1("EXTENSION", |options, extenion|{
-            options.extensions.push(OsString::from(extenion));
+        Option::new("-e", "--extension", "Add search EXTENSION (or)", Handler::Args1("EXTENSION", |options, extension|{
+            options.extensions.push(OsString::from(extension));
+            Ok(())
+        })),
+        Option::new("-E", "--extension-set", "Add search EXTENSION_SET (or)", Handler::Args1("EXTENSION_SET", |options, extenion_set|{
+            options.extension_sets.push(OsString::from(extenion_set));
             Ok(())
         })),
         Option::new("-a", "--binary", "Search binary files as well [false]", Handler::Args0(|options|{
@@ -221,6 +238,24 @@ impl Options {
             }
         }
 
+        //Translate extension_sets into extensions
+        {
+            let extension_sets = self.extension_sets.clone();
+            for extension_set in extension_sets.iter() {
+                let mut add_extension = |extension|{
+                    self.extensions.push(OsString::from(extension))
+                };
+                if extension_set == &OsString::from("c") {
+                    add_extension("c");
+                    add_extension("h");
+                    add_extension("cpp");
+                    add_extension("hpp");
+                } else {
+                    fail!("Unknown extension set {}", extension_set.to_string_lossy())
+                }
+            }
+        }
+
         Ok(())
     }
 
@@ -305,6 +340,11 @@ fn test_options_parse() {
             parse_ok: true,
             options: Options{output_help: true, ..Options::default()},
         },
+        Scn{
+            args: vec!["-v"],
+            parse_ok: true,
+            options: Options{invert_pattern: true, ..Options::default()},
+        },
         Scn{
             args: vec!["-C", "ROOT"],
             parse_ok: true,
